@@ -291,9 +291,9 @@ sim_brain_1h <- function(acq_paras = def_acq_paras(), type = "normal_v1",
                          pul_seq = seq_press_ideal, xlim = c(0.5, 4.2), 
                          full_output = FALSE, amps = NULL,  ...) {
   
+  brain_basis_paras <- get_1h_brain_basis_paras_v1(ft = acq_paras$ft)
   if (is.null(amps)) {
     if (type == "normal_v1") {
-      brain_basis_paras <- get_1h_brain_basis_paras_v1(ft = acq_paras$ft)
       amps <- c(0.000000000, 0.009799548, 0.072152490, 0.077845526, 0.045575002, 
                 0.005450371, 0.000000000, 0.028636132, 0.076469056, 0.028382618,
                 0.069602483, 0.001763720, 0.042031981, 0.013474549, 0.000000000, 
@@ -549,4 +549,24 @@ ginv <- function(X, tol = sqrt(.Machine$double.eps)) {
     array(0, dim(X)[2L:1L])
   else Xsvd$v[, Positive, drop = FALSE] %*% ((1/Xsvd$d[Positive]) * 
                                            t(Xsvd$u[, Positive, drop = FALSE]))
+}
+
+matexp <- function(x) {
+  d  <- dim(x)
+  n  <- d[1]
+  p  <- d[2]
+  Ar <- Re(x)
+  Ai <- Im(x)
+  E  <- rbind(cbind(Ar, -Ai), cbind(Ai, Ar))
+  eE <- expm::expm(E)
+  eA <- eE[1:n, 1:n] + (0+1i) * eE[(1:n) + n, 1:n]
+  eA <- matrix(Imzap(eA), ncol = n)
+  return(eA)
+}
+
+# fn taken from complexplus package
+Imzap <- function(x, tol = 1e-06) {
+  if (all(abs(Im(z <- zapsmall(x))) <= tol)) 
+    as.double(x)
+  else x
 }
\ No newline at end of file
